package com.lantone.report.facade;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.lantone.dto.appeal.GetAppealInfoDTO;
import com.lantone.dto.appeal.GetAppealReviewDTO;
import com.lantone.dto.appeal.GetComplaintRecordDTO;
import com.lantone.common.enums.IsDeleteEnum;
import com.lantone.common.exception.Asserts;
import com.lantone.vo.appeal.*;
import com.lantone.appeal.entity.AppealExamineInfo;
import com.lantone.appeal.entity.AppealInfo;
import com.lantone.report.facade.base.analyze.MedQcresultDetailFacade;
import com.lantone.report.facade.base.appeal.AppealExamineInfoFacade;
import com.lantone.report.facade.base.appeal.AppealInfoFacade;
import com.lantone.report.client.MedAppealExamineInfoServiceClient;
import com.lantone.report.enums.AppealOperationTypeEnum;
import com.lantone.report.enums.ExampleStatusEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * @Description:申述记录
 * @Author: songxl
 * @Date 2022/1/5
 */
@Component
public class MedAppealExamineInfoManagementFacade {
    @Autowired
    private AppealExamineInfoFacade appealExamineInfoFacade;
    @Autowired
    private MedQcresultDetailFacade medQcresultDetailFacade;
    @Autowired
    private AppealInfoFacade appealInfoFacade;
    @Autowired
    MedAppealExamineInfoServiceClient medAppealExamineInfoServiceClient;
    @Autowired
    MedAppealInfoManagementFacade medAppealInfoManagementFacade;
    /**
     * 申诉记录
     * @param getComplaintRecordVO
     * @return
     */
    public Page<GetComplaintRecordDTO> getComplaintRecord(GetComplaintRecordVO getComplaintRecordVO) {
        return appealExamineInfoFacade.getBaseMapper().getComplaintRecord(getComplaintRecordVO);
    }

    /**
     * 申诉审核列表
     * @param getAppealReviewVO
     * @return
     */
    public Page<GetAppealReviewDTO> getAppealReview(GetAppealReviewVO getAppealReviewVO) {
        return appealExamineInfoFacade.getBaseMapper().getAppealReview(getAppealReviewVO);
    }

/*
    */
/**
     * 审核通过
     * @param approvedVo
     * @return
     *//*

    public Boolean approved (ApprovedVo approvedVo) {
        QcresultVO qcresultVO = new QcresultVO();
        qcresultVO.setBehospitalCode(approvedVo.getBehospitalCode());
        qcresultVO.setHospitalId(approvedVo.getHospitalId());
        QcResultAlgVO qcResultAlgVO = new QcResultAlgVO();
        qcResultAlgVO.setCasesId(approvedVo.getCasesId());
        qcResultAlgVO.setScore(approvedVo.getValue());
        qcResultAlgVO.setMsg(approvedVo.getCasesEntryMsg());
        //获取处理方式
        String handling = approvedVo.getExampleOperation();
        if (StringUtil.isNotEmpty(handling) && handling.equals("删除")) {
            //调用删除接口
            qcResultAlgVO.setCasesEntryId(approvedVo.getQcresultDetailId());
            qcresultVO.setOptResultAlgVO(qcResultAlgVO);
            qcresultVO.setDelStatus(1);
            RespDTO<AnalyzeDTO> analyzeDTORespDTO = medAppealExamineInfoServiceClient.logicDelCase(qcresultVO);
            if (analyzeDTORespDTO.data.getIsSuccess()) {
                Boolean appealInfo = updateAppealInfo(approvedVo);
                AppealExamineInfo appealExamineInfo = new AppealExamineInfo();
                appealExamineInfo.setExampleOperation("2");
                appealExamineInfo.setExampleStatus("2");
                appealExamineInfo.setRemark(approvedVo.getRemark());
                appealExamineInfo.setAppealInfoId(approvedVo.getAppealId());
                int appealExamineInfoUpdate = appealExamineInfoFacade.getBaseMapper().update(appealExamineInfo, new QueryWrapper<AppealExamineInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("appeal_info_id", approvedVo.getId())
                        .eq("check_id", approvedVo.getAppealId())
                );
                if (appealInfo && appealExamineInfoUpdate == 1) {
                    return true;
                } else {
                    Asserts.fail2("审核通过失败!");
                    return false;
                }
            } else {
                Asserts.fail2("删除失败!");
                return false;
            }
        }
        if (StringUtil.isNotEmpty(handling) && handling.equals("修改")) {
            //调用修改接口
            qcResultAlgVO.setCasesEntryId(approvedVo.getQcresultDetailId());
            qcresultVO.setOptResultAlgVO(qcResultAlgVO);
            RespDTO<AnalyzeDTO> analyzeDTORespDTO = medAppealExamineInfoServiceClient.updCase(qcresultVO);
            if (analyzeDTORespDTO.data.getIsSuccess()) {
                Boolean appealInfo = updateAppealInfo(approvedVo);
                AppealExamineInfo appealExamineInfo = new AppealExamineInfo();
                appealExamineInfo.setExampleOperation("1");
                appealExamineInfo.setExampleStatus("2");
                appealExamineInfo.setRemark(approvedVo.getRemark());
                appealExamineInfo.setAppealInfoId(approvedVo.getAppealId());
                int appealExamineInfoUpdate = appealExamineInfoFacade.getBaseMapper().update(appealExamineInfo, new QueryWrapper<AppealExamineInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("appeal_info_id", approvedVo.getId())
                        .eq("check_id", approvedVo.getAppealId())
                );
                if (appealInfo && appealExamineInfoUpdate == 1) {
                    return true;
                } else {
                    Asserts.fail2("审核通过失败!");
                    return false;
                }
            } else {
                Asserts.fail2("修改!");
                return false;
            }
        }
        if (StringUtil.isNotEmpty(handling) && handling.equals("新增已有")) {
            qcResultAlgVO.setCasesEntryId(approvedVo.getCasesEntryId());
            qcresultVO.setOptResultAlgVO(qcResultAlgVO);
            //判断是否已存在该条目
            MedQcresultDetail qcresultDetail = medQcresultDetailFacade.getBaseMapper().selectOne(new QueryWrapper<MedQcresultDetail>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", approvedVo.getHospitalId())
                    .eq("behospital_code", approvedVo.getBehospitalCode())
                    .eq("cases_entry_id", approvedVo.getCasesEntryId())
            );
            if (qcresultDetail != null) {
                Asserts.fail2("该条目已存在");
                return false;
            }
            //调用新增接口
            RespDTO<AnalyzeDTO> analyzeDTORespDTO = medAppealExamineInfoServiceClient.addCase(qcresultVO);
            if (analyzeDTORespDTO.data.getIsSuccess()) {
                AppealInfo appealInfo = new AppealInfo();
                appealInfo.setCasesEntryId(approvedVo.getCasesEntryId());
                appealInfo.setCasesEntryMsg(approvedVo.getCasesEntryMsg());
                appealInfo.setCasesEntryName(approvedVo.getCasesEntryName());
                appealInfo.setValue(approvedVo.getValue());
                int appealInfoUpdate = appealInfoFacade.getBaseMapper().update(appealInfo, new QueryWrapper<AppealInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", approvedVo.getHospitalId())
                        .eq("behospital_code", approvedVo.getBehospitalCode())
                        .eq("id", approvedVo.getAppealId())
                );
                AppealExamineInfo appealExamineInfo = new AppealExamineInfo();
                appealExamineInfo.setExampleOperation("3");
                appealExamineInfo.setExampleStatus("2");
                appealExamineInfo.setRemark(approvedVo.getRemark());
                appealExamineInfo.setAppealInfoId(approvedVo.getAppealId());
                int appealExamineInfoUpdate = appealExamineInfoFacade.getBaseMapper().update(appealExamineInfo, new QueryWrapper<AppealExamineInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("appeal_info_id", approvedVo.getId())
                        .eq("check_id", approvedVo.getAppealId())
                );
                if (appealInfoUpdate == 1 && appealExamineInfoUpdate == 1) {
                    return true;
                } else {
                    Asserts.fail2("审核通过失败!");
                    return false;
                }
            } else {
                Asserts.fail2("新增失败!");
                return false;
            }
        }
        if (StringUtil.isNotEmpty(handling) && handling.equals("恢复")) {
            qcResultAlgVO.setCasesEntryId(approvedVo.getQcresultDetailId());
            qcresultVO.setOptResultAlgVO(qcResultAlgVO);
            qcresultVO.setDelStatus(0);
            //调用删除接口
            RespDTO<AnalyzeDTO> analyzeDTORespDTO = medAppealExamineInfoServiceClient.logicDelCase(qcresultVO);
            if (analyzeDTORespDTO.data.getIsSuccess()) {
                Boolean appealInfo = updateAppealInfo(approvedVo);
                AppealExamineInfo appealExamineInfo = new AppealExamineInfo();
                appealExamineInfo.setExampleOperation("5");
                appealExamineInfo.setExampleStatus("2");
                appealExamineInfo.setRemark(approvedVo.getRemark());
                appealExamineInfo.setAppealInfoId(approvedVo.getAppealId());
                int appealExamineInfoUpdate = appealExamineInfoFacade.getBaseMapper().update(appealExamineInfo, new QueryWrapper<AppealExamineInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("appeal_info_id", approvedVo.getId())
                        .eq("check_id", approvedVo.getAppealId())
                );
                if (appealInfo && appealExamineInfoUpdate == 1) {
                    return true;
                } else {
                    Asserts.fail2("审核通过失败!");
                    return false;
                }
            } else {
                Asserts.fail2("恢复失败!");
                return false;
            }
        }
        if (StringUtil.isNotEmpty(handling) && handling.equals("新增缺失")) {
            qcResultAlgVO.setCasesEntryId(approvedVo.getQcresultDetailId());
            qcresultVO.setOptResultAlgVO(qcResultAlgVO);
            qcresultVO.setDelStatus(0);
            Boolean appealInfo = updateAppealInfo(approvedVo);
            AppealExamineInfo appealExamineInfo = new AppealExamineInfo();
            appealExamineInfo.setExampleOperation("4");
            appealExamineInfo.setExampleStatus("2");
            appealExamineInfo.setProcessResult(approvedVo.getProcessResult());
            appealExamineInfo.setAppealInfoId(approvedVo.getAppealId());
            int appealExamineInfoUpdate = appealExamineInfoFacade.getBaseMapper().update(appealExamineInfo, new QueryWrapper<AppealExamineInfo>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("appeal_info_id", approvedVo.getId())
                    .eq("check_id", approvedVo.getAppealId())
            );
            if (appealInfo && appealExamineInfoUpdate == 1) {
                return true;
            } else {
                Asserts.fail2("审核通过失败!");
                return false;
            }
        }
            Asserts.fail2("无此类型处理方式!");
            return false;
    }
*/


    /**
     * 驳回
     * @param rejectedVo
     * @return
     */
    public Boolean rejected(RejectedVo rejectedVo) {
        AppealInfo appealInfo = new AppealInfo();
        appealInfo.setWorkFlowNodeId(rejectedVo.getWorkFlowNodeId());
        int appealInfoUpdate = appealInfoFacade.getBaseMapper().update(appealInfo, new UpdateWrapper<AppealInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", rejectedVo.getHospitalId())
                .eq("behospital_code", rejectedVo.getBehospitalCode())
                .eq("check_id", rejectedVo.getAppealId())
                .eq("id",rejectedVo.getId())
        );
        AppealExamineInfo appealExamineInfo = new AppealExamineInfo();
        appealExamineInfo.setExampleStatus(ExampleStatusEnum.REJECT_EXAMPLE.getKey());
        appealExamineInfo.setGmtCreate(new Date());
        appealExamineInfo.setRejectReason(rejectedVo.getRejectedReason());
        int appealExamineInfoUpdate = appealExamineInfoFacade.getBaseMapper().update(appealExamineInfo, new UpdateWrapper<AppealExamineInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("appeal_info_id", rejectedVo.getId())
                .eq("check_id", rejectedVo.getAppealId())
        );
        if(appealInfoUpdate==1 && appealExamineInfoUpdate==1){
            return true;
        }else {
            Asserts.fail2("驳回失败!");
            return false;
        }
    }

    /**
     * 获取待审核数量
     * @param getAuditNumberVO
     * @return
     */
    public Integer getAuditNumber(GetAuditNumberVO getAuditNumberVO) {
        Integer count = appealExamineInfoFacade.getBaseMapper().selectCount(new QueryWrapper<AppealExamineInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("check_id", getAuditNumberVO.getId())
                .eq("example_status", 0)
        );
        return count;
    }
    /**
     * 审核查看
     * @param getAppealInfoVO
     * @return
     */
    public GetAppealInfoDTO getApprovedView(GetAppealInfoVO getAppealInfoVO) {
        //1.获取病历基本信息和病历内容
        GetAppealInfoDTO getAppealInfoDTO =  appealInfoFacade.getBaseMapper().getAppealInfo(getAppealInfoVO);
        //2.获取该条申诉记录详情
        AppealInfo appealInfo = appealInfoFacade.getById(getAppealInfoVO.getId());
        if(appealInfo!=null){
            //如果是新增缺失，获取申诉说明（通过申诉说明区别该病历新增的新增缺失）
            if(AppealOperationTypeEnum.ADD_NO_EXIST.getKey().equals(appealInfo.getAppealOperationType())){
                getAppealInfoVO.setAppealExplain(appealInfo.getAppealExplain());
            }
        }
        //3.获取申诉审核记录
        getAppealInfoDTO.setAppealExamineRecordDTOList(appealInfoFacade.getBaseMapper().getAppealExamineRecords(getAppealInfoVO));
        return getAppealInfoDTO;
    }

    public Boolean updateAppealInfo (ApprovedVo approvedVo) {
        AppealInfo appealInfo = new AppealInfo();
        int appealInfoUpdate = appealInfoFacade.getBaseMapper().update(appealInfo, new UpdateWrapper<AppealInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", approvedVo.getHospitalId())
                .eq("behospital_code", approvedVo.getBehospitalCode())
                .eq("id", approvedVo.getAppealId())
        );
        if(appealInfoUpdate==1){
            return true;
        }else {
            return false;
        }
    }
}
