package com.lantone.report.web;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.lantone.common.api.CommonResult;
import com.lantone.dto.report.BehospitalInfoDTO;
import com.lantone.dto.report.CheckInfoDTO;
import com.lantone.dto.report.DoctorAdviceDTO;
import com.lantone.dto.report.ExamineInfoDTO;
import com.lantone.dto.report.ExamineSonInfoDTO;
import com.lantone.dto.report.GetModuleInfoOneDTO;
import com.lantone.dto.report.QcCasesAllDTO;
import com.lantone.vo.report.BehospitalPageVO;
import com.lantone.vo.report.CheckInfoVO;
import com.lantone.vo.report.DoctorAdviceVO;
import com.lantone.vo.report.ExamineInfoVO;
import com.lantone.vo.report.ExamineSonInfoVO;
import com.lantone.vo.report.ExportQcresultVO;
import com.lantone.vo.report.GetDetailVO;
import com.lantone.vo.report.GetModuleMapVO;
import com.lantone.vo.report.MedNurseInfoVO;
import com.lantone.vo.report.QcCasesEntryVO;
import com.lantone.report.entity.Nurse;
import com.lantone.report.facade.MrInfoFacade;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 病历列表相关API
 * </p>
 * @author zhaops
 * @since 2020-04-27
 */

@RestController
@RequestMapping("/qc")
@Api(value = "病历列表相关API", tags = { "病历列表相关API" })
@SuppressWarnings("unchecked")
public class MrInfoController {
    @Autowired
    private MrInfoFacade mrInfoFacade;

    @ApiOperation(value = "病历列表-报表[by:zhoutg]")
    @PostMapping("/behospitalInfo/page")
    public CommonResult<IPage<BehospitalInfoDTO>> page(@RequestBody BehospitalPageVO behospitalPageVO) {
        IPage<BehospitalInfoDTO> data = mrInfoFacade.pageFac(behospitalPageVO);
        return CommonResult.success(data);
    }

    @ApiOperation(value = "病历列表-报表导出[by:zhaops]")
    @PostMapping("/behospitalInfo/exportQcresult")
    public void exportQcresult(HttpServletResponse response, @RequestBody ExportQcresultVO exportQcresultVO) {
        mrInfoFacade.exportQcresult(response, exportQcresultVO);
    }

    @ApiOperation(value = "根据病历id获取详情[by:zhoutg]")
    @PostMapping("/behospitalInfo/getByBehospitalCode")
    public CommonResult<Map<String, Object>> getByBehospitalCode(@RequestBody GetDetailVO getDetailVO) {
        Map<String, Object> data = mrInfoFacade.getByBehospitalCode(getDetailVO);
        return CommonResult.success(data);
    }

    @ApiOperation(value = "护理信息API[by:cy]")
    @PostMapping("/medNurse/getMedNursePage")
    public CommonResult<IPage<Nurse>> getMedNursePage(@RequestBody @Valid MedNurseInfoVO medNurseInfoVO) {
        return  CommonResult.success(mrInfoFacade.getMedNursePage(medNurseInfoVO));
    }

    @ApiOperation(value = "获取检查信息[by:cy]")
    @PostMapping("/medPacsInfo/getCheckPage")
    public CommonResult<IPage<CheckInfoDTO>> getCheckPage(@RequestBody @Valid CheckInfoVO checkInfoVO) {
        return  CommonResult.success(mrInfoFacade.getCheckPage(checkInfoVO));
    }

    @ApiOperation(value = "获取检验信息[by:cy]")
    @PostMapping("/medLisInfo/getExaminePage")
    public CommonResult<IPage<ExamineInfoDTO>> getExaminePage(@RequestBody @Valid ExamineInfoVO examineInfoVO) {
        return CommonResult.success(mrInfoFacade.getExaminePage(examineInfoVO));
    }

    @ApiOperation(value = "获取检验子项信息[by:cy]")
    @PostMapping("/medLisInfo/getExamineSonPage")
    public CommonResult<IPage<ExamineSonInfoDTO>> getExamineSonPage(@RequestBody @Valid ExamineSonInfoVO examineSonInfoVO) {
        return CommonResult.success(mrInfoFacade.getExamineSonPage(examineSonInfoVO));
    }

    @ApiOperation(value = "获取医嘱信息[by:gaodm]")
    @PostMapping("/doctoradvice/getPage")
    public CommonResult<IPage<DoctorAdviceDTO>> getPage(@RequestBody @Valid DoctorAdviceVO doctorAdviceVO) {
        return CommonResult.success(mrInfoFacade.getPageFac(doctorAdviceVO));
    }

    @ApiOperation(value = "根据模块获取模板信息[by:zhoutg]")
    @PostMapping("/module/getModuleMap")
    public CommonResult<Map<Long, GetModuleInfoOneDTO>> getModuleMap(@RequestBody GetModuleMapVO getModuleMapVO) {
        Map<Long, GetModuleInfoOneDTO> data = mrInfoFacade.getModuleMap(getModuleMapVO);
        return CommonResult.success(data);
    }

    @ApiOperation(value = "获取医院模块数据列表[by:wangfeng]")
    @PostMapping("/casesEntryHospital/getQcCasesAll")
    public CommonResult<List<QcCasesAllDTO>> getQcCasesAlls(@RequestBody @Valid QcCasesEntryVO qcCasesEntryVO) {
        return CommonResult.success(mrInfoFacade.getQcCasesAlls(qcCasesEntryVO));
    }
}
